@@ -1,16 +1,17 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 import datetime
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
 from trytond.pyson import Not, Bool, Eval, Equal, PYSONEncoder, Date
 from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 STATES = {
     'readonly': Not(Bool(Eval('active'))),
 }
+DEPENDS = ['active']
 
 
 class Location(ModelSQL, ModelView):
@@ -18,14 +19,16 @@ class Location(ModelSQL, ModelView):
     _name = 'stock.location'
     _description = __doc__
     name = fields.Char("Name", size=None, required=True, states=STATES,
-            translate=True)
-    code = fields.Char("Code", size=None, states=STATES, select=1)
+        depends=DEPENDS, translate=True)
+    code = fields.Char("Code", size=None, states=STATES, depends=DEPENDS,
+        select=1)
     active = fields.Boolean('Active', select=1)
     address = fields.Many2One("party.address", "Address",
-            states={
-                'invisible': Not(Equal(Eval('type'), 'warehouse')),
-                'readonly': Not(Bool(Eval('active'))),
-            })
+        states={
+            'invisible': Not(Equal(Eval('type'), 'warehouse')),
+            'readonly': Not(Bool(Eval('active'))),
+            },
+        depends=['type', 'active'])
     type = fields.Selection([
         ('supplier', 'Supplier'),
         ('customer', 'Customer'),
@@ -34,7 +37,7 @@ class Location(ModelSQL, ModelView):
         ('storage', 'Storage'),
         ('production', 'Production'),
         ('view', 'View'),
-        ], 'Location type', states=STATES)
+        ], 'Location type', states=STATES, depends=DEPENDS)
     parent = fields.Many2One("stock.location", "Parent", select=1,
             left="left", right="right")
     left = fields.Integer('Left', required=True, select=1)
@@ -45,14 +48,15 @@ class Location(ModelSQL, ModelView):
             'invisible': Not(Equal(Eval('type'), 'warehouse')),
             'readonly': Not(Bool(Eval('active'))),
             'required': Equal(Eval('type'), 'warehouse'),
-        },
+            },
         domain=[
             ('type','=','storage'),
             ['OR',
-                ('parent', 'child_of', [Eval('active_id')]),
+                ('parent', 'child_of', [Eval('id')]),
                 ('parent', '=', False),
+                ],
             ],
-        ])
+        depends=['type', 'active', 'id'])
     output_location = fields.Many2One(
         "stock.location", "Output", states={
             'invisible': Not(Equal(Eval('type'), 'warehouse')),
@@ -61,8 +65,9 @@ class Location(ModelSQL, ModelView):
         },
         domain=[('type','=','storage'),
             ['OR',
-                ('parent', 'child_of', [Eval('active_id')]),
-                ('parent', '=', False)]])
+                ('parent', 'child_of', [Eval('id')]),
+                ('parent', '=', False)]],
+        depends=['type', 'active', 'id'])
     storage_location = fields.Many2One(
         "stock.location", "Storage", states={
             'invisible': Not(Equal(Eval('type'), 'warehouse')),
@@ -71,8 +76,9 @@ class Location(ModelSQL, ModelView):
         },
         domain=[('type','=','storage'),
             ['OR',
-                ('parent', 'child_of', [Eval('active_id')]),
-                ('parent', '=', False)]])
+                ('parent', 'child_of', [Eval('id')]),
+                ('parent', '=', False)]],
+        depends=['type', 'active', 'id'])
     quantity = fields.Function(fields.Float('Quantity'), 'get_quantity')
     forecast_quantity = fields.Function(fields.Float('Forecast Quantity'),
             'get_quantity')
@@ -101,7 +107,7 @@ class Location(ModelSQL, ModelView):
     def check_type_for_moves(self, ids):
         """ Check locations with moves have types compatible with moves. """
         invalid_move_types = ['warehouse', 'view']
-        move_obj = self.pool.get('stock.move')
+        move_obj = Pool().get('stock.move')
         for location in self.browse(ids):
             if location.type in invalid_move_types and \
                 move_obj.search(['OR',
@@ -135,8 +141,8 @@ class Location(ModelSQL, ModelView):
         return [(self._rec_name,) + tuple(clause[1:])]
 
     def get_quantity(self, ids, name):
-        product_obj = self.pool.get('product.product')
-        date_obj = self.pool.get('ir.date')
+        product_obj = Pool().get('product.product')
+        date_obj = Pool().get('ir.date')
 
         if (not Transaction().context.get('product')) \
                 or not (isinstance(Transaction().context['product'],
@@ -168,7 +174,7 @@ class Location(ModelSQL, ModelView):
         return dict([(loc,qty) for (loc,prod), qty in pbl])
 
     def view_header_get(self, value, view_type='form'):
-        product_obj = self.pool.get('product.product')
+        product_obj = Pool().get('product.product')
         value = super(Location, self).view_header_get(value,
                 view_type=view_type)
         if (Transaction().context.get('product')
@@ -199,11 +205,11 @@ class Location(ModelSQL, ModelView):
                     location_ids.add(location.output_location.id)
                 if not location.storage_location.parent:
                     location_ids.add(location.storage_location.id)
-        location_ids = list(location_ids)
-        if location_ids:
-            self.write(location_ids, {
-                'parent': location.id,
-                })
+                if location_ids:
+                    self.write(list(location_ids), {
+                        'parent': location.id,
+                        })
+                    location_ids.clear()
 
     def create(self, vals):
         res = super(Location, self).create(vals)
@@ -323,7 +329,7 @@ class ChooseStockDateInit(ModelView):
             '* A date in the past will provide historical values.')
 
     def default_forecast_date(self):
-        date_obj = self.pool.get('ir.date')
+        date_obj = Pool().get('ir.date')
         return date_obj.today()
 
 ChooseStockDateInit()
@@ -353,8 +359,8 @@ class OpenProduct(Wizard):
     }
 
     def _action_open_product(self, data):
-        model_data_obj = self.pool.get('ir.model.data')
-        act_window_obj = self.pool.get('ir.action.act_window')
+        model_data_obj = Pool().get('ir.model.data')
+        act_window_obj = Pool().get('ir.action.act_window')
         act_window_id = model_data_obj.get_id('stock',
                 'act_product_by_location')
         res = act_window_obj.read(act_window_id)
